

Overview
========

.. htmlonly::

    :Release: |version|
    :Date: |today|

    Download `PDF <http://matplotlib.sf.net/Matplotlib.pdf>`_


.. toctree::
   :maxdepth: 2

   users/index.rst
   faq/index.rst
   devel/index.rst
   mpl_toolkits/index.rst
   api/index.rst
   glossary/index.rst

.. htmlonly::
   - `Examples <examples/index.html>`_

  * :ref:`genindex`
  * :ref:`modindex`
  * :ref:`search`
